@@ -93,7 +93,7 @@ private Q_SLOTS:
         for (MessageNotification* notif : std::as_const(MessageNotification::mNotificationList))
         {
             const QByteArray group = "Notification_" + QByteArray::number(++n);
-            KConfigGroup cg(config, QLatin1String(group.constData()));
+            KConfigGroup cg(config, QLatin1StringView(group.constData()));
             notif->saveProperties(cg);
         }
         KConfigGroup cg(config, QStringLiteral("Number"));
@@ -556,7 +556,7 @@ void MessageNotification::enableEditButton(bool enable)
 * Save settings to the session managed config file, for restoration
 * when the program is restored.
 */
-void MessageNotification::saveProperties(KConfigGroup& config)
+void MessageNotification::saveProperties(KConfigGroup& config)     //cppcheck-suppress[constParameterReference]  config is changed
 {
     Q_UNUSED(config)
 #ifdef RESTORE_NOTIFICATIONS
