@@ -1,7 +1,7 @@
 /*
  *  pluginmanager.cpp  -  plugin manager
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2022-2025 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -13,6 +13,7 @@
 #include <QObject>
 
 class AkonadiPlugin;
+class AudioPlugin;
 
 class KALARMPLUGINLIB_EXPORT PluginManager : public QObject
 {
@@ -23,12 +24,18 @@ public:
     static PluginManager* instance();
 
     void loadPlugins();
-    AkonadiPlugin* akonadiPlugin() const;
+    AkonadiPlugin*      akonadiPlugin() const;
+    QList<AudioPlugin*> audioPlugins() const;
+    AudioPlugin*        audioMpvPlugin() const;
+    AudioPlugin*        audioVlcPlugin() const;
 
 private:
     explicit PluginManager(QObject* parent = nullptr);
 
-    AkonadiPlugin* mAkonadiPlugin {nullptr};
+    AkonadiPlugin*      mAkonadiPlugin {nullptr};
+    AudioPlugin*        mAudioMpvPlugin {nullptr};
+    AudioPlugin*        mAudioVlcPlugin {nullptr};
+    QList<AudioPlugin*> mAudioPlugins;
 };
 
 // vim: et sw=4:
