@@ -12,6 +12,7 @@
 #include <KConfigGroup>
 
 #include <QFileInfo>
+using namespace Qt::Literals::StringLiterals;
 
 namespace
 {
@@ -30,15 +31,15 @@ const char* KEY_UPDATEFORMAT = "UpdateFormat";
 const char* KEY_HASH         = "Hash";
 const char* KEY_CMDERRORS    = "CommandErrors";
 // Config file values
-const QLatin1String STORAGE_FILE("File");
-const QLatin1String STORAGE_DIR("Dir");
-const QLatin1String ALARM_ACTIVE("Active");
-const QLatin1String ALARM_ARCHIVED("Archived");
-const QLatin1String ALARM_TEMPLATE("Template");
-const QLatin1String CMD_ERROR_VALUE("Main");
-const QLatin1String CMD_ERROR_PRE_VALUE("Pre");
-const QLatin1String CMD_ERROR_POST_VALUE("Post");
-const QLatin1String CMD_ERROR_PRE_POST_VALUE("PrePost");
+const QLatin1StringView STORAGE_FILE("File");
+const QLatin1StringView STORAGE_DIR("Dir");
+const QLatin1StringView ALARM_ACTIVE("Active");
+const QLatin1StringView ALARM_ARCHIVED("Archived");
+const QLatin1StringView ALARM_TEMPLATE("Template");
+const QLatin1StringView CMD_ERROR_VALUE("Main");
+const QLatin1StringView CMD_ERROR_PRE_VALUE("Pre");
+const QLatin1StringView CMD_ERROR_POST_VALUE("Post");
+const QLatin1StringView CMD_ERROR_PRE_POST_VALUE("PrePost");
 const QLatin1Char   CMD_ERROR_SEPARATOR(':');
 }
 
@@ -99,10 +100,10 @@ bool FileResourceSettings::readConfig()
     mStandard          = readAlarmTypes(KEY_STANDARD);
 
     // Read storage type and validate against location.
-    const QString storageType = mConfigGroup->readEntry(KEY_TYPE, QString());
-    if (storageType == STORAGE_FILE)
+    const QString storeType = mConfigGroup->readEntry(KEY_TYPE, QString());
+    if (storeType == STORAGE_FILE)
         mStorageType = File;
-    else if (storageType == STORAGE_DIR)
+    else if (storeType == STORAGE_DIR)
         mStorageType = Directory;
     else
     {
@@ -508,18 +509,18 @@ bool FileResourceSettings::validate()
 
 CalEvent::Types FileResourceSettings::readAlarmTypes(const char* key) const
 {
-    CalEvent::Types alarmTypes {CalEvent::EMPTY};
+    CalEvent::Types alrmTypes {CalEvent::EMPTY};
     const QStringList types = mConfigGroup->readEntry(key, QStringList());
     for (const QString& type : types)
     {
         if (type == ALARM_ACTIVE)
-            alarmTypes |= CalEvent::ACTIVE;
+            alrmTypes |= CalEvent::ACTIVE;
         else if (type == ALARM_ARCHIVED)
-            alarmTypes |= CalEvent::ARCHIVED;
+            alrmTypes |= CalEvent::ARCHIVED;
         else if (type == ALARM_TEMPLATE)
-            alarmTypes |= CalEvent::TEMPLATE;
+            alrmTypes |= CalEvent::TEMPLATE;
     }
-    return alarmTypes;
+    return alrmTypes;
 }
 
 QString FileResourceSettings::alarmTypesString(CalEvent::Types alarmTypes)
@@ -531,7 +532,7 @@ QString FileResourceSettings::alarmTypesString(CalEvent::Types alarmTypes)
         types += ALARM_ARCHIVED;
     if (alarmTypes & CalEvent::TEMPLATE)
         types += ALARM_TEMPLATE;
-    return types.join(QLatin1Char(','));
+    return types.join(','_L1);
 }
 
 FileResourceSettings::Storage FileResourceSettings::storageType(const QUrl& url)
